summaryrefslogtreecommitdiff
path: root/configs/ruby
diff options
context:
space:
mode:
authorTushar Krishna <tushar@ece.gatech.edu>2016-10-06 14:35:14 -0400
committerTushar Krishna <tushar@ece.gatech.edu>2016-10-06 14:35:14 -0400
commitaca869bf2dba8cc7a7b06be223b84fa0376a59e9 (patch)
tree85c82c75158f88133bad87ea4b9c877ed42d23fd /configs/ruby
parent3f0118876f109d0fb94f06687e8d695835a03636 (diff)
downloadgem5-aca869bf2dba8cc7a7b06be223b84fa0376a59e9.tar.xz
ruby: rename ALPHA_Network_test protocol to Garnet_standalone.
Over the past 6 years, we realized that the protocol is essentially used to run the garnet network in a standalone manner, and feed standard synthetic traffic patterns through it.
Diffstat (limited to 'configs/ruby')
-rw-r--r--configs/ruby/Garnet_standalone.py (renamed from configs/ruby/Network_test.py)18
1 files changed, 9 insertions, 9 deletions
diff --git a/configs/ruby/Network_test.py b/configs/ruby/Garnet_standalone.py
index df3985cc1..2897e73a4 100644
--- a/configs/ruby/Network_test.py
+++ b/configs/ruby/Garnet_standalone.py
@@ -1,5 +1,5 @@
-# Copyright (c) 2006-2007 The Regents of The University of Michigan
# Copyright (c) 2009 Advanced Micro Devices, Inc.
+# Copyright (c) 2016 Georgia Institute of Technology
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
@@ -26,6 +26,7 @@
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# Authors: Brad Beckmann
+# Tushar Krishna
import m5
from m5.objects import *
@@ -42,22 +43,21 @@ def define_options(parser):
return
def create_system(options, full_system, system, dma_ports, ruby_system):
-
- if buildEnv['PROTOCOL'] != 'Network_test':
- panic("This script requires the Network_test protocol to be built.")
+ if buildEnv['PROTOCOL'] != 'Garnet_standalone':
+ panic("This script requires Garnet_standalone protocol to be built.")
cpu_sequencers = []
#
# The Garnet tester protocol does not support fs nor dma
#
assert(dma_ports == [])
#
# The ruby network creation expects the list of nodes in the system to be
- # consistent with the NetDest list. Therefore the l1 controller nodes must be
- # listed before the directory nodes and directory nodes before dma nodes, etc.
- #
+ # consistent with the NetDest list.
+ # Therefore the l1 controller nodes must be listed before
+ # the directory nodes and directory nodes before dma nodes, etc.
l1_cntrl_nodes = []
dir_cntrl_nodes = []
@@ -84,7 +84,7 @@ def create_system(options, full_system, system, dma_ports, ruby_system):
cpu_seq = RubySequencer(icache = cache,
dcache = cache,
- using_network_tester = True,
+ garnet_standalone = True,
ruby_system = ruby_system)
l1_cntrl.sequencer = cpu_seq
@@ -42,22 +43,21 @@ def define_options(parser):
cpu_sequencers = []
#
- # The Garnet tester protocol does not support fs nor dma
+ # The Garnet_standalone protocol does not support fs nor dma
#
assert(dma_ports == [])